/******************************************************************************

    agedriv.c

    Copyright Nicola Salmoria and the MAME Team.
    Visit http://mamedev.org for licensing and usage restrictions.

    The list of all available drivers. Drivers have to be included here to be
    recognized by the executable.

    To save some typing, we use a hack here. This file is recursively #included
    twice, with different definitions of the DRIVER() macro. The first one
    declares external references to the drivers; the second one builds an array
    storing all the drivers.

******************************************************************************/

#include "driver.h"

#ifndef DRIVER_RECURSIVE

#define DRIVER_RECURSIVE

/* step 1: declare all external references */
#define DRIVER(NAME) extern game_driver driver_##NAME;
#include "agedriv.c"

/* step 2: define the drivers[] array */
#undef DRIVER
#define DRIVER(NAME) &driver_##NAME,
const game_driver * const drivers[] =
{
#include "agedriv.c"
	0	/* end of array */
};

#else	/* DRIVER_RECURSIVE */

	/* Ace Coin Electronics (ACE) */
	DRIVER( sidewndr )	/* (c) 1981? ACE */
	DRIVER( spellbnd )	/* (c) 1981? ACE */
	DRIVER( starspnr )	/* (c) 1982? ACE */
	DRIVER( acefruit )	/* (c) 1982? ACE */

	DRIVER( skill98 )	/* (c) 1998 Amcoe */
	DRIVER( match98 )	/* (c) 1998 Amcoe */
	DRIVER( schery97 )	/* (c) 1998 Amcoe */
	DRIVER( schery97a )	/* (c) 1998 Amcoe */
	DRIVER( roypok96 )	/* (c) 1996 Amcoe */
	DRIVER( roypok96a )	/* (c) 1996 Amcoe */
	DRIVER( roypok96b )	/* (c) 1996 Amcoe */
	DRIVER( pokonl97 )	/* (c) 1997 Amcoe */
	DRIVER( nc96 )		/* (c) 1996 Amcoe */
	DRIVER( nc96a )		/* (c) 1996 Amcoe */
	DRIVER( nc96b )		/* (c) 1996 Amcoe */
	DRIVER( nc96c )		/* (c) 1996 Amcoe */
	DRIVER( nc96txt )	/* (c) 2000 Amcoe */
	DRIVER( nfb96 )		/* (c) 1996 Amcoe */
	DRIVER( nfb96a )	/* (c) 1996 Amcoe */
	DRIVER( nfb96b )	/* (c) 1996 Amcoe */
	DRIVER( nfb96c )	/* (c) 1996 Amcoe */
	DRIVER( nfb96txt )	/* (c) 2000 Amcoe */
	DRIVER( nfb96se )	/* bootleg */
	DRIVER( nfb96sea )	/* bootleg */
	DRIVER( nfb96seb )	/* bootleg */
	DRIVER( carb2002 )	/* bootleg */
	DRIVER( carb2003 )	/* bootleg */
	DRIVER( nfm )		/* bootleg */
	DRIVER( unkch1 )	/* bootleg */
	DRIVER( unkch2 )	/* bootleg */
	DRIVER( unkch3 )	/* bootleg */
	DRIVER( unkch4 )	/* bootleg */

	DRIVER( sfbonus )	/* (c) 2003 Amcoe - Skill Fruit Bonus */
	DRIVER( sfbonusd1 )	/* (c) 2003 Amcoe */
	DRIVER( sfbonusv1 )	/* (c) 2003 Amcoe */
	DRIVER( sfbonuso )	/* (c) 2003 Amcoe */
	DRIVER( sfbonuso2 )	/* (c) 2003 Amcoe */
	DRIVER( parrot3 )	/* (c) 2003 Amcoe - Parrot Poker III */
	DRIVER( parrot3b1 )	/* (c) 2004 Amcoe */
	DRIVER( parrot3d1 )	/* (c) 2004 Amcoe */
	DRIVER( parrot3v1 )	/* (c) 2004 Amcoe */
	DRIVER( parrot3o )	/* (c) 2004 Amcoe */
	DRIVER( hldspin1 )	/* (c) 2000 Amcoe - Hold & Spin I */
	DRIVER( hldspin1dt )/* (c) 2000 Amcoe */
	DRIVER( hldspin1vt )/* (c) 2000 Amcoe */
	DRIVER( hldspin1o )	/* (c) 2000 Amcoe */
	DRIVER( hldspin2 )	/* (c) 2000 Amcoe - Hold & Spin II */
	DRIVER( hldspin2d1 )/* (c) 2000 Amcoe */
	DRIVER( hldspin2v1 )/* (c) 2000 Amcoe */
	DRIVER( hldspin2o )	/* (c) 2000 Amcoe */
	DRIVER( fcnudge )	/* (c) 2003 Amcoe - Fruit Carnival Nudge */
	DRIVER( fcnudgeo )	/* (c) 2003 Amcoe */
	DRIVER( fcnudgeo2 )	/* (c) 2003 Amcoe */
	DRIVER( fcnudgeo3 )	/* (c) 2003 Amcoe */
	DRIVER( pickwin )	/* (c) 2001 Amcoe - Pick 'n Win */
	DRIVER( pickwinb1 )	/* (c) 2001 Amcoe */
	DRIVER( pickwind1 )	/* (c) 2001 Amcoe */
	DRIVER( pickwinv1 )	/* (c) 2001 Amcoe */
	DRIVER( pickwinbt )	/* (c) 2001 Amcoe */
	DRIVER( pickwindt )	/* (c) 2001 Amcoe */
	DRIVER( pickwinvt )	/* (c) 2001 Amcoe */
	DRIVER( pickwino )	/* (c) 2001 Amcoe */
	DRIVER( pickwino2 )	/* (c) 2001 Amcoe */
	DRIVER( tighook )	/* (c) 2004 Amcoe - Tiger Hook */
	DRIVER( tighookc1 )	/* (c) 2004 Amcoe */
	DRIVER( tighookd1 )	/* (c) 2004 Amcoe */
	DRIVER( tighookv1 )	/* (c) 2004 Amcoe */
	DRIVER( tighookc2 )	/* (c) 2004 Amcoe */
	DRIVER( tighookd2 )	/* (c) 2004 Amcoe */
	DRIVER( tighookv2 )	/* (c) 2004 Amcoe */
	DRIVER( tighooko )	/* (c) 2004 Amcoe */
	DRIVER( tighooko2 )	/* (c) 2004 Amcoe */
	DRIVER( robadv )	/* (c) 2004 Amcoe - Robin's Adventure */
	DRIVER( robadvc1 )	/* (c) 2004 Amcoe */
	DRIVER( robadvd1 )	/* (c) 2004 Amcoe */
	DRIVER( robadvv1 )	/* (c) 2004 Amcoe */
	DRIVER( robadvo )	/* (c) 2004 Amcoe */
	DRIVER( robadv2 )	/* (c) 2004 Amcoe - Robin's Adventure 2 */
	DRIVER( robadv2c1 )	/* (c) 2004 Amcoe */
	DRIVER( robadv2d1 )	/* (c) 2004 Amcoe */
	DRIVER( robadv2v1 )	/* (c) 2004 Amcoe */
	DRIVER( robadv2c2 )	/* (c) 2004 Amcoe */
	DRIVER( robadv2d2 )	/* (c) 2004 Amcoe */
	DRIVER( robadv2v2 )	/* (c) 2004 Amcoe */
	DRIVER( robadv2c3 )	/* (c) 2004 Amcoe */
	DRIVER( robadv2d3 )	/* (c) 2004 Amcoe */
	DRIVER( robadv2v3 )	/* (c) 2004 Amcoe */
	DRIVER( robadv2o )	/* (c) 2004 Amcoe */
	DRIVER( robadv2o2 )	/* (c) 2004 Amcoe */
	DRIVER( pirpok2 )	/* (c) 2003 Amcoe - Pirate Poker II */
	DRIVER( pirpok2b1 )	/* (c) 2003 Amcoe */
	DRIVER( pirpok2d1 )	/* (c) 2003 Amcoe */
	DRIVER( pirpok2v1 )	/* (c) 2003 Amcoe */
	DRIVER( pirpok2o )	/* (c) 2003 Amcoe */
	DRIVER( anibonus )	/* (c) 2003 Amcoe - Animal Bonus */
	DRIVER( anibonusv1 )/* (c) 2003 Amcoe */
	DRIVER( anibonusv2 )/* (c) 2003 Amcoe */
	DRIVER( anibonusb1 )/* (c) 2003 Amcoe */
	DRIVER( anibonusd1 )/* (c) 2003 Amcoe */
	DRIVER( anibonusb2 )/* (c) 2003 Amcoe */
	DRIVER( anibonusd2 )/* (c) 2003 Amcoe */
	DRIVER( anibonuso )	/* (c) 2003 Amcoe */
	DRIVER( anibonuso2 )/* (c) 2003 Amcoe */
	DRIVER( anibonuso3 )/* (c) 2003 Amcoe */
	DRIVER( anibonusxo )/* (c) 2003 Amcoe */
	DRIVER( anibonusxo2 )/* (c) 2003 Amcoe */
	DRIVER( anibonusxo3 )/* (c) 2003 Amcoe */
	DRIVER( abnudge )	/* (c) 2003 Amcoe - Animal Bonus Nudge */
	DRIVER( abnudgeb )	/* (c) 2003 Amcoe */
	DRIVER( abnudged )	/* (c) 2003 Amcoe */
	DRIVER( abnudgeo )	/* (c) 2003 Amcoe */
	DRIVER( dblchal )	/* (c) 2003 Amcoe - Double Challenge */
	DRIVER( dblchalc1 )	/* (c) 2003 Amcoe */
	DRIVER( dblchald1 )	/* (c) 2003 Amcoe */
	DRIVER( dblchalv1 )	/* (c) 2003 Amcoe */
	DRIVER( dblchalo )	/* (c) 2003 Amcoe */
	DRIVER( anithunt )	/* (c) 2003 Amcoe - Animal Treasure Hunt */
	DRIVER( anithuntd1 )/* (c) 2003 Amcoe */
	DRIVER( anithuntv1 )/* (c) 2003 Amcoe */
	DRIVER( anithunto )	/* (c) 2003 Amcoe */
	DRIVER( anithunto2 )/* (c) 2003 Amcoe */
	DRIVER( sfruitb )	/* (c) 2002 Amcoe - Super Fruit Bonus */
	DRIVER( sfruitbb1 )	/* (c) 2002 Amcoe */
	DRIVER( sfruitbd1 )	/* (c) 2002 Amcoe */
	DRIVER( sfruitbv1 )	/* (c) 2002 Amcoe */
	DRIVER( sfruitbb2 )	/* (c) 2002 Amcoe */
	DRIVER( sfruitbd2 )	/* (c) 2002 Amcoe */
	DRIVER( sfruitbv2 )	/* (c) 2002 Amcoe */
	DRIVER( sfruitbo )	/* (c) 2002 Amcoe */
	DRIVER( sfruitbo2 )	/* (c) 2002 Amcoe */
	DRIVER( sfruitbh )	/* (c) 2002 Amcoe */
	DRIVER( sfruitbbh )	/* (c) 2002 Amcoe */
	DRIVER( sfruitbdh )	/* (c) 2002 Amcoe */
	DRIVER( sfruitbvh )	/* (c) 2002 Amcoe */
	DRIVER( sfruitboh )	/* (c) 2002 Amcoe */
	DRIVER( fb2gen )	/* (c) 2004 Amcoe - Fruit Bonus 2nd Generation */
	DRIVER( fb2genc1 )	/* (c) 2004 Amcoe */
	DRIVER( fb2gend1 )	/* (c) 2004 Amcoe */
	DRIVER( fb2genv1 )	/* (c) 2004 Amcoe */
	DRIVER( fb2genc2 )	/* (c) 2004 Amcoe */
	DRIVER( fb2gend2 )	/* (c) 2004 Amcoe */
	DRIVER( fb2genv2 )	/* (c) 2004 Amcoe */
	DRIVER( fb2geno )	/* (c) 2004 Amcoe */
	DRIVER( fb2geno2 )	/* (c) 2004 Amcoe */
	DRIVER( fb2nd )		/* (c) 2004 Amcoe - Fruit Bonus 2nd Edition */
	DRIVER( fb2ndd1 )	/* (c) 2004 Amcoe */
	DRIVER( fb2ndv1 )	/* (c) 2004 Amcoe */
	DRIVER( fb2ndc2 )	/* (c) 2004 Amcoe */
	DRIVER( fb2ndd2 )	/* (c) 2004 Amcoe */
	DRIVER( fb2ndv2 )	/* (c) 2004 Amcoe */
	DRIVER( fb2ndo )	/* (c) 2004 Amcoe */
	DRIVER( fb4 )		/* (c) 2004 Amcoe - Fruit Bonus 2004 */
	DRIVER( fb4c1 )		/* (c) 2004 Amcoe */
	DRIVER( fb4d1 )		/* (c) 2004 Amcoe */
	DRIVER( fb4v1 )		/* (c) 2004 Amcoe */
	DRIVER( fb4exp )	/* (c) 2004 Amcoe */
	DRIVER( fb4b2 )		/* (c) 2004 Amcoe */
	DRIVER( fb4c2 )		/* (c) 2004 Amcoe */
	DRIVER( fb4d2 )		/* (c) 2004 Amcoe */
	DRIVER( fb4v2 )		/* (c) 2004 Amcoe */
	DRIVER( fb4o )		/* (c) 2004 Amcoe */
	DRIVER( fb4o2 )		/* (c) 2004 Amcoe */
	DRIVER( fb5 )		/* (c) 2005 Amcoe - Fruit Bonus 2005 */
	DRIVER( fb5c )		/* (c) 2005 Amcoe */
	DRIVER( fb5d )		/* (c) 2005 Amcoe */
	DRIVER( fb5v )		/* (c) 2005 Amcoe */
	DRIVER( fb6 )		/* (c) 200? Amcoe - Fruit Bonus '06 - 10th anniversary */
	DRIVER( fb6v )		/* (c) 200? Amcoe */
	DRIVER( fb6d1 )		/* (c) 200? Amcoe */
	DRIVER( fb6s1 )		/* (c) 200? Amcoe */
	DRIVER( fb6v1 )		/* (c) 200? Amcoe */
	DRIVER( fb6d2 )		/* (c) 200? Amcoe */
	DRIVER( fb6s2 )		/* (c) 200? Amcoe */
	DRIVER( fb6v2 )		/* (c) 200? Amcoe */
	DRIVER( fb6se )		/* (c) 200? Amcoe - Fruit Bonus 2006 Special Edition */
	DRIVER( fb6sev )	/* (c) 200? Amcoe */
	DRIVER( fb6sed1 )	/* (c) 200? Amcoe */
	DRIVER( fb6sev1 )	/* (c) 200? Amcoe */
	DRIVER( fb6sed2 )	/* (c) 200? Amcoe */
	DRIVER( fb6sev2 )	/* (c) 200? Amcoe */
	DRIVER( version4 )	/* (c) 200? Amcoe - Version 4 ? */
	DRIVER( bugfever )	/* (c) 200? Amcoe - Bug Fever */
	DRIVER( bugfeverd )	/* (c) 200? Amcoe */
	DRIVER( bugfeverv )	/* (c) 200? Amcoe */
	DRIVER( bugfeverv2 )/* (c) 200? Amcoe */
	DRIVER( dvisland )	/* (c) 200? Amcoe - Devil's Island */
	DRIVER( funriver )	/* (c) 200? Amcoe - Fun River */
	DRIVER( funriverv )	/* (c) 200? Amcoe */
	DRIVER( amclink )	/* (c) 200? Amcoe - Amcoe Link Control Box? */

	DRIVER( act2000 )	/* (c) 1999 Amcoe - Action 2000 */
	DRIVER( act2000v1 )	/* (c) 1999 Amcoe */
	DRIVER( act2000d1 )	/* (c) 1999 Amcoe */
	DRIVER( act2000b1 )	/* (c) 1999 Amcoe */
	DRIVER( act2000vx )	/* (c) 1999 Amcoe */
	DRIVER( act2000dx )	/* (c) 1999 Amcoe */
	DRIVER( act2000bx )	/* (c) 1999 Amcoe */
	DRIVER( act2000o )	/* (c) 1999 Amcoe */
	DRIVER( act2000o2 )	/* (c) 1999 Amcoe */
	DRIVER( act2000o3 )	/* (c) 1999 Amcoe */
	DRIVER( ch2000 )	/* (c) 2000 Amcoe - Fruit Bonus 2000 / New Cherry 2000 */
	DRIVER( ch2000b1 )	/* (c) 2000 Amcoe */
	DRIVER( ch2000c1 )	/* (c) 2000 Amcoe */
	DRIVER( ch2000d1 )	/* (c) 2000 Amcoe */
	DRIVER( ch2000v1 )	/* (c) 2000 Amcoe */
	DRIVER( ch2000b2 )	/* (c) 2000 Amcoe */
	DRIVER( ch2000c2 )	/* (c) 2000 Amcoe */
	DRIVER( ch2000d2 )	/* (c) 2000 Amcoe */
	DRIVER( ch2000v2 )	/* (c) 2000 Amcoe */
	DRIVER( ch2000o )	/* (c) 2000 Amcoe */
	DRIVER( ch2000o2 )	/* (c) 2000 Amcoe */
	DRIVER( ch2000o3 )	/* (c) 2000 Amcoe */
	DRIVER( pir2001 )	/* (c) 2001 Amcoe - Pirate 2001 */
	DRIVER( pir2001b1 )	/* (c) 2001 Amcoe */
	DRIVER( pir2001d1 )	/* (c) 2001 Amcoe */
	DRIVER( pir2001v1 )	/* (c) 2001 Amcoe */
	DRIVER( pir2001bx )	/* (c) 2001 Amcoe */
	DRIVER( pir2001dx )	/* (c) 2001 Amcoe */
	DRIVER( pir2001vx )	/* (c) 2001 Amcoe */
	DRIVER( pir2001o )	/* (c) 2001 Amcoe */
	DRIVER( pir2001o2 )	/* (c) 2001 Amcoe */
	DRIVER( pir2001o3 )	/* (c) 2001 Amcoe */
	DRIVER( pir2002 )	/* (c) 2001 Amcoe - Pirate 2002 */
	DRIVER( pir2002b1 )	/* (c) 2001 Amcoe */
	DRIVER( pir2002d1 )	/* (c) 2001 Amcoe */
	DRIVER( pir2002v1 )	/* (c) 2001 Amcoe */
	DRIVER( pir2002bx )	/* (c) 2001 Amcoe */
	DRIVER( pir2002dx )	/* (c) 2001 Amcoe */
	DRIVER( pir2002vx )	/* (c) 2001 Amcoe */
	DRIVER( pir2002o )	/* (c) 2001 Amcoe */
	DRIVER( pir2002o2 )	/* (c) 2001 Amcoe */
	DRIVER( pir2002o3 )	/* (c) 2001 Amcoe */
	DRIVER( classice )	/* (c) 2004 Amcoe - Classic Edition */
	DRIVER( classicev )	/* (c) 2004 Amcoe */
	DRIVER( classice1 )	/* (c) 2004 Amcoe */
	DRIVER( classiced1 )/* (c) 2004 Amcoe */
	DRIVER( classicev1 )/* (c) 2004 Amcoe */
	DRIVER( classice2 )	/* (c) 2004 Amcoe */
	DRIVER( classiced2 )/* (c) 2004 Amcoe */
	DRIVER( classicev2 )/* (c) 2004 Amcoe */
	DRIVER( seawld )	/* (c) 200? Amcoe - Sea World */
	DRIVER( seawldd1 )	/* (c) 200? Amcoe */
	DRIVER( moneymac )	/* (c) 200? Amcoe - Money Machine */
	DRIVER( moneymacd1 )/* (c) 200? Amcoe */
	DRIVER( moneymacv1 )/* (c) 200? Amcoe */
	DRIVER( moneymacd2 )/* (c) 200? Amcoe */
	DRIVER( moneymacv2 )/* (c) 200? Amcoe */
	//DRIVER( atworld ) /* (c) 2007 Amcoe - Around The World (year listed on Amcoe web site) */
	//DRIVER( atworldd1 )   /* (c) 2007 Amcoe (year listed on Amcoe web site) */

	/* AMT */
	DRIVER( cabaret )	/* (c) 1992 AMT */

	/* Aristocrat */
	DRIVER( 86lions )	/* (c) 1985? */
	DRIVER( caswin )	/* (c) 1985 */

	/* Aristocrat Mk4 hardware */
	DRIVER( 3bagflnz )	/* (c) 1994 */
	DRIVER( blkrhino )	/* (c) 1996 */
	DRIVER( coralr2 )	/* (c) 2002 */
	DRIVER( eforest )	/* (c) 1994 */
	DRIVER( eforesta )	/* (c) 1995 */
	DRIVER( eforestb )	/* (c) 1996 */
	DRIVER( goldenc )	/* (c) 1996 */
	DRIVER( kgbird )	/* (c) 1996 */
	DRIVER( kgbirda )	/* (c) 1996 */
	DRIVER( phantomp )	/* (c) 1998 */
	DRIVER( swtht2nz )	/* (c) 1998 */
	DRIVER( topgear )	/* (c) 1996 */

	/* Aristocrat Mk5 hardware */
	DRIVER( swthrt2v )	/* (c) 1995 */
	DRIVER( enchfrst )	/* (c) 1995 */
	DRIVER( dolphntr )	/* (c) 1996 */
	DRIVER( dolphtra )	/* (c) 1996 */
	DRIVER( dmdtouch )	/* (c) 1997 */
	DRIVER( goldprmd )	/* (c) 1997 */
	DRIVER( qotn )		/* (c) 1997 */
	DRIVER( adonis )	/* (c) 1998 */
	DRIVER( reelrock )	/* (c) 1998 */
	DRIVER( indiandr )	/* (c) 1998 */
	DRIVER( margmgc )	/* (c) 2000 */

	/* Astro Corp. */
	DRIVER( showhand )	/* (c) 1999? Astro Corp. */
	DRIVER( showhanc )	/* (c) 1999? Astro Corp. */

	/* AWP/ABM */
	DRIVER( magic10 )	/* (c) 1995 A.W.P. Games */
	DRIVER( magic10a )	/* (c) 1995 A.W.P. Games */
	DRIVER( magic10b )	/* (c) 1995 A.W.P. Games */
	DRIVER( magic102 )	/* (c) 1997 ABM Games */
	DRIVER( suprpool )	/* (c) 1997 ABM Games */
	DRIVER( hotslot )   /* (c) 1996 ABM Electronics */
	DRIVER( sgsafari )	/* (c) 1996 New Impeuropex Corp. */

	DRIVER( galaxi )	/* (c) 2000 BRL S.R.L. Bologna */
	DRIVER( magjoker )	/* (c) 2000 BRL S.R.L. Bologna */

	/* Barcrest */
	/* MPU3/4 Games */
	DRIVER( dealem )
	DRIVER( connect4 )	/* Dolbeck Systems */
	DRIVER( mpu4utst )
	DRIVER( mpu4tst2 )
	DRIVER( mpu4met0 )

	DRIVER( bctvidbs )	/* Barcrest */
	DRIVER( crmaze )	/* Barcrest */
	DRIVER( crmazea )	/* Barcrest */
	DRIVER( crmazeb )	/* Barcrest */
	DRIVER( mating )	/* Barcrest */
	DRIVER( matinga )	/* Barcrest */
	DRIVER( skiltrek )	/* Barcrest */
	DRIVER( turnover )	/* Barcrest */
	DRIVER( timemchn )	/* Barcrest */
	DRIVER( vgpoker )	/* BwB? */

	/* BellFruit Manufacturing/Gaming (BFM/BFG) and partners */

	/* Adder (Scorpion2 Video) games            PROM A      GAME CARD*/
	DRIVER( qntoondo  )	/* (c) 1994 BFM/ELAM   PR6097V1    95-750-136*/
	DRIVER( quintono  )	/* (c) 1993 BFM UK     QUIN V3     95-750-203*/
	DRIVER( quintoon  )	/* (c) 1993 BFM UK     QUIN V3     95-750-206*/
	DRIVER( quintond  )	/* (c) 1993 BFM UK     QUIN V3     95-751-206*/
	DRIVER( qntoond   )	/* (c) 1994 BFM/ELAM   PR6097V1    95-750-243*/
	DRIVER( pokio     )	/* (c) 1994 BFM/ELAM   PR6343V1    95-750-278*/
	DRIVER( paradice  )	/* (c) 1995 BFM/ELAM   PR6444V2    95-750-615*/
	DRIVER( pyramid   )	/* (c) 1996 BFM/ELAM   PR6644V5    95-750-898*/
	DRIVER( slotsnl   )	/* (c) 1995 BFM/ELAM   PR6349V1    95-750-368*/
	DRIVER( sltblgtk  )	/* (c) 1996 BFM/ELAM   PR6496V2    95-750-943*/
	DRIVER( sltblgpo  )	/* (c) 1996 BFM/ELAM   PR6495V5    95-750-938   Belgian slots cash payout*/
	DRIVER( sltblgp1  )	/* (c) 1996 BFM/ELAM   PR6495V5    95-752-008   Belgian slots cash payout*/
	DRIVER( gldncrwn  )	/* (c) 1997 BFM/ELAM   PR6750V1    95-752-011*/

	/* Bell Fruit Cobra Hardware */
	DRIVER( inquiztr )	/* 1989 BFM */
	DRIVER( escounts )	/* 1990 BFM */
	DRIVER( trebltop )	/* 1991 BFM */
	DRIVER( beeline )	/* 1991 BFM */
	DRIVER( quizvadr )	/* 1991 BFM */
	DRIVER( qos )		/* 1992 BFM */
	DRIVER( qosa )		/* 1992 BFM */
	DRIVER( qosb )		/* 1992 BFM */

	/* BS Electronics */
	DRIVER( carrera )	/* (c) 19?? BS Electronics */

	/* Bonanza Enterprises */
	DRIVER( miniboy7 )	/* (c) 1983, Bonanza Enterprises */
	
	/* Bordun International */
	DRIVER( skylncr )	/* (c) 1995 Bordun International */
	DRIVER( butrfly )	/* (c) 1995 Bordun International */
	DRIVER( madzoo )	/* (c) 1995 Bordun International */
	DRIVER( leader )	/* Bootleg? */

	/* BrezzaSoft (NeoGeo hardware)*/
	DRIVER( neogeo )
	DRIVER( vliner )
	DRIVER( vlinero )

	/* Cal Omega */
	DRIVER( comg074 )	/* (c) 1981 Cal Omega Inc. */
	DRIVER( comg076 )	/* (c) 1981 Cal Omega Inc. */
	DRIVER( comg079 )	/* (c) 1981 Cal Omega Inc. */
	DRIVER( comg080 )	/* (c) 1981 Cal Omega Inc. */
	DRIVER( comg094 )	/* (c) 1981 Cal Omega Inc. */
	DRIVER( comg107 )	/* (c) 1982 Cal Omega Inc. */
	DRIVER( comg123 )	/* (c) 1982 Cal Omega Inc. */
	DRIVER( comg125 )	/* (c) 1982 Cal Omega Inc. */
	DRIVER( comg127 )	/* (c) 1982 Cal Omega Inc. */
	DRIVER( comg128 )	/* (c) 1982 Cal Omega Inc. */
	DRIVER( comg134 )	/* (c) 1982 Cal Omega Inc. */
	DRIVER( comg145 )	/* (c) 1982 Cal Omega Inc. */
	DRIVER( comg157 )	/* (c) 1983 Cal Omega Inc. */
	DRIVER( comg159 )	/* (c) 1983 Cal Omega Inc. */
	DRIVER( comg164 )	/* (c) 1983 Cal Omega Inc. */
	DRIVER( comg168 )	/* (c) 1983 Cal Omega Inc. */
	DRIVER( comg172 )	/* (c) 1983 Cal Omega Inc. */
	DRIVER( comg175 )	/* (c) 1984 Cal Omega / Casino Electronics Inc. */
	DRIVER( comg176 )	/* (c) 1982 Cal Omega Inc. */
	DRIVER( comg181 )	/* (c) 1983 Cal Omega Inc. */
	DRIVER( comg183 )	/* (c) 1983 Cal Omega Inc. */
	DRIVER( comg185 )	/* (c) 1983 Cal Omega Inc. */
	DRIVER( comg186 )	/* (c) 1983 Cal Omega Inc. */
	DRIVER( comg187 )	/* (c) 1983 Cal Omega Inc. */
	DRIVER( comg204 )	/* (c) 1984 Cal Omega Inc. */
	DRIVER( comg208 )	/* (c) 1984 Cal Omega Inc. */
	DRIVER( comg227 )	/* (c) 1984 Cal Omega Inc. */
	DRIVER( comg230 )	/* (c) 1984 Cal Omega Inc. */
	DRIVER( comg236 )	/* (c) 1984 Cal Omega Inc. */
	DRIVER( comg239 )	/* (c) 1985 Cal Omega / Casino Electronics Inc. */
	DRIVER( comg246 )	/* (c) 1985 Cal Omega Inc. */
	DRIVER( comg272a )	/* (c) 1985 Cal Omega Inc. */
	DRIVER( comg272b )	/* (c) 1985 Cal Omega Inc. */
	DRIVER( comg903d )	/* (c) 198? Cal Omega Inc. */
	DRIVER( comg905d )	/* (c) 198? Cal Omega Inc. */
	DRIVER( elgrande )	/* (c) 1982 Tuni Electro Service / E.T. Marketing */
	DRIVER( jjpoker )	/* (c) 1983 Enter-Tech */
	DRIVER( jjpokerb )	/* (c) 1983 Enter-Tech */
	DRIVER( ssipkr24 )	/* (c) 1988 SSI */
	DRIVER( ssipkr30 )	/* (c) 1988 SSI */
	DRIVER( ssipkr40 )	/* (c) 1990 SSI */

	/* Coinmaster */
	DRIVER( quizmstr )	/* (c) 1985 Coinmaster */
	DRIVER( trailblz )	/* (c) 1987 Coinmaster */
	DRIVER( supnudg2 )	/* (c) 1989 Coinmaster */
	DRIVER( pokeroul ) 	/* (c) 1990 Coinmaster */

	/* Coinmaster-Gaming VGA based */
	DRIVER( colorama )	/* (c) 2001 Coinmaster-Gaming, Ltd. */
	DRIVER( cmrltv75 )	/* (c) 2001 Coinmaster-Gaming, Ltd. */
	DRIVER( cmkenosp )	/* (c) 2000 Coinmaster-Gaming, Ltd. */
	DRIVER( cmkenospa )	/* (c) 2000 Coinmaster-Gaming, Ltd. */

	/* Dyna */
	DRIVER( cb2001 )	/* (c) 2001 Dyna Electronics */
	DRIVER( scherrym )	/* (c) 2001? Dyna Electronics */

	DRIVER( ncb3 )		/* (c) 199? Dyna Electronics */
	DRIVER( cb3a )		/* (c) 199? Dyna Electronics */
	DRIVER( cb3 )		/* (c) 199? Dyna Electronics */
	DRIVER( cb3b )		/* (c) 199? Dyna Electronics */
	DRIVER( cmv801 )	/* (c) 198? Corsica */
	DRIVER( cmv4 )		/* (c) 1992 Dyna Electronics */
	DRIVER( cmv4a )		/* (c) 1992 Dyna Electronics */
	DRIVER( cmaster )	/* (c) 1991 Dyna Electronics */
	DRIVER( cmasterb )	/* (c) 1991 Dyna Electronics */
	DRIVER( cmasterc )	/* (c) 1991 Dyna Electronics */
	DRIVER( cmast91 )	/* (c) 1991 Dyna Electronics */

	DRIVER( rcasino )	/* (c) 1984 Dyna Electronics */

	/* Eagle */
	DRIVER( janshi )

	/* Electrocoin */
	DRIVER( dmndrby )	/* (c) 1986 Electrocoin */
	DRIVER( dmndrbya )	/* (c) 1986 Electrocoin */

	/* Electronic Products */
	DRIVER( jackpool )  /* (c) 1997 Electronic Projects */
	DRIVER( mcolors )   /* 1999 unknown */

	/* Electronic Projects */
	DRIVER( spool99 )	/* (c) 1998 Electronic Projects */
	DRIVER( spool99a )	/* (c) 1998 Electronic Projects */

	/* Entretenimientos GEMINIS */
	DRIVER( re900 )		/* (c) 1993 Entretenimientos GEMINIS */
	DRIVER( bs94 )		/* (c) 1994 Entretenimientos GEMINIS */

	/* Funworld */
	DRIVER( jollycrd )	/* (c) 1985 TAB-Austria */
	DRIVER( jolyc3x3 )	/* (c) 1985 TAB-Austria */
	DRIVER( jolyc980 )	/* (c) 2000 Spale-Soft */
	DRIVER( jolycdev )	/* (c) 1998 TAB/Evona */
	DRIVER( jolyccra )	/* (c) 1985 TAB-Austria */
	DRIVER( jolyccrb )	/* (c) 1993 Soft Design */
	DRIVER( jolycdit )	/* 199? bootleg */
	DRIVER( jolycdib )	/* 1990 bootleg */
	DRIVER( sjcd2kx3 )	/* (c) 1985 M.P.*/
	DRIVER( jolycdab )	/* (c) 1986 Inter Games */
	DRIVER( bigdeal )	/* (c) 1986 Funworld */
	DRIVER( bigdealb )	/* (c) 1986 Funworld */
	DRIVER( jolycdat )	/* (c) 1986 Funworld */
	DRIVER( cuoreuno )	/* (c) 1996 C.M.C. */
	DRIVER( elephfam )	/* (c) 1997 C.M.C. */
	DRIVER( elephfmb )	/* (c) 1996 C.M.C. */
	DRIVER( pool10 )	/* (c) 1996 C.M.C. */
	DRIVER( pool10b )	/* (c) 1996 C.M.C. */
	DRIVER( pool10c )	/* (c) 1996 C.M.C. */
	DRIVER( pool10d )	/* (c) 1997 C.M.C. */
	DRIVER( tortufam )	/* (c) 1997 C.M.C. */
	DRIVER( potgame )	/* (c) 1996 C.M.C. */
	DRIVER( bottle10 )	/* (c) 1996 C.M.C. */
	DRIVER( bottl10b )	/* (c) 1996 C.M.C. */
	DRIVER( royalcrd )	/* (c) 1991 TAB-Austria */
	DRIVER( royalcdb )	/* (c) 1991 TAB-Austria */
	DRIVER( royalcdc )	/* (c) 1991 Evona Electronic */
	DRIVER( royalcdp )	/* (c) 1993 Digital Dreams */
	DRIVER( lluck3x3 )	/* (c) 1991 TAB-Austria */
	DRIVER( lluck4x1 )	/* (c) 1991 TAB-Austria */
	DRIVER( magicrd2 )	/* (c) 1996 Impera */
	DRIVER( magicd2a )	/* (c) 1996 Impera */
	DRIVER( magicd2b )	/* (c) 1996 Impera */
	DRIVER( vegasslw )	/* (c) 1993 Funworld */
	DRIVER( vegasfst )	/* (c) 1993 Soft Design */
	DRIVER( vegasfte )	/* (c) 1993 Soft Design */
	DRIVER( jolyjokr )	/* (c) 198? Impera */
	DRIVER( jolyjkra )	/* (c) 198? Impera */
	DRIVER( jokercrd )	/* (c) 1993 Vesely Svet */
	DRIVER( mongolnw )	/* 199? bootleg */
	DRIVER( soccernw )	/* 199? bootleg */
	DRIVER( saloon )	/* 199? unknown */

	/* Impera */
	DRIVER( magicard )	/* (c) 199? */
	DRIVER( magicarda )	/* (c) 199? */
	DRIVER( magicardb )	/* (c) 199? */

	/* Sandii' */
	DRIVER( snookr10 )	/* (c) 1998 Sandii' */
	DRIVER( apple10 )	/* (c) 1998 Sandii' */
	DRIVER( tenballs )	/* 1997 unknown */

	/* Game-A-Tron */
	DRIVER( poker41 )	/* (c) 1983 Game-A-Tron */
	DRIVER( pulltabs )	/* (c) 1983 Game-A-Tron */

	/* Golden Poker / Potten's Poker / Witch Card hardware */
	DRIVER( pmpoker )	/* (c) 1981 PlayMan */
	DRIVER( goldnpkr )	/* (c) 1981 Bonanza */
	DRIVER( goldnpkb )	/* (c) 1981 Bonanza */
	DRIVER( pottnpkr )	/* Bootleg */
	DRIVER( potnpkra )	/* Bootleg in Coinmaster H/W */
	DRIVER( potnpkrb )	/* Bootleg */
	DRIVER( potnpkrc )	/* Bootleg */
	DRIVER( potnpkrd )	/* Bootleg */
	DRIVER( potnpkre )	/* Bootleg */
	DRIVER( goodluck )	/* Unknown */
	DRIVER( royale )	/* Unknown */
	DRIVER( royalea )	/* Unknown */
	DRIVER( witchcrd )	/* 1991, Video Klein */
	DRIVER( witchcda )	/* 1991, Unknown */
	DRIVER( witchcdb )	/* 1991, Unknown */
	DRIVER( witchcdc )	/* 1991, Unknown */
	DRIVER( witchcdd )	/* 1991, Unknown */
	DRIVER( witchcde )	/* 1994, Unknown */
	DRIVER( witchcdf )	/* (c) 1991 PlayMan */
	DRIVER( sloco93 )	/* 1993, Unknown */
	DRIVER( sloco93a )	/* 1993, Unknown */
	DRIVER( maverik )	/* 198?, Unknown */
	DRIVER( brasil89 )	/* 1989, Unknown */
	DRIVER( poker91 )	/* 1991, Unknown */
	DRIVER( bsuerte )	/* 1990, Unknown */
	DRIVER( bsuertea )	/* 1991, Unknown */
	DRIVER( bsuerteb )	/* 1991, Unknown */
	DRIVER( bsuertec )	/* 1991, Unknown */
	DRIVER( bsuerted )	/* 1991, Unknown */
	DRIVER( bsuertee )	/* 1991, Unknown */
	DRIVER( bsuertef )	/* 1991, Unknown */
	DRIVER( bsuerteg )	/* 1991, Unknown */
	DRIVER( bsuerteh )	/* 1991, Unknown */
	DRIVER( bsuertei )	/* 1991, Unknown */
	DRIVER( bsuertej )	/* 1991, Unknown */
	DRIVER( bsuertek )	/* 1991, Unknown */
	DRIVER( bsuertel )	/* 1991, Unknown */
	DRIVER( bsuertem )	/* 1991, Unknown */
	DRIVER( bsuerten )	/* 1991, Unknown */
	DRIVER( bsuerteo )	/* 1991, Unknown */
	DRIVER( bsuertep )	/* 1991, Unknown */
	DRIVER( bsuerteq )	/* 1991, Unknown */
	DRIVER( bsuerter )	/* 1991, Unknown */
	DRIVER( bsuertes )	/* 1991, Unknown */
	DRIVER( bsuertet )	/* 1991, Unknown */
	DRIVER( bsuerteu )	/* 1991, Unknown */

	/* Greyhound Electronics */
	DRIVER( jokpoker )	/* (c) 1982 Greyhound Electronics */
	DRIVER( superbwl )	/* (c) 1982 Greyhound Electronics */
	DRIVER( amuse )		/* (c) 1982 Greyhound Electronics */
	DRIVER( gs4002 )	/* (c) 1982 G.E.I. */
	DRIVER( gs4002a )	/* (c) 1982 G.E.I. */

	DRIVER( gepoker )	/* (c) 1984 Greyhound Electronics */
	DRIVER( gepoker1 )	/* (c) 1984 Greyhound Electronics */
	DRIVER( gepoker2 )	/* (c) 1984 Greyhound Electronics */
	DRIVER( gtsers1 )	/* (c) 1984 Greyhound Electronics */
	DRIVER( gtsers2 )	/* (c) 1984 Greyhound Electronics */
	DRIVER( gtsers3 )	/* (c) 1984 Greyhound Electronics */
	DRIVER( gtsers4 )	/* (c) 1984 Greyhound Electronics */
	DRIVER( gtsers5 )	/* (c) 1985 Greyhound Electronics */
	DRIVER( gtsers7 )	/* (c) 1985 Greyhound Electronics */
	DRIVER( gtsersa )	/* (c) 1985 Greyhound Electronics */
	DRIVER( gtsersb )	/* (c) 1985 Greyhound Electronics */

	/* High Video */
	/* V30-based italian gambling games */
 	DRIVER( tour4000 )	/* (c) 2000 High Video */
 	DRIVER( cfever40 )	/* (c) 2000 High Video */
 	DRIVER( cfever50 )	/* (c) 2000 High Video */
 	DRIVER( tour4010 )	/* (c) 2000 High Video */
 	DRIVER( cfever51 )	/* (c) 2000 High Video */
 	DRIVER( cfever61 )	/* (c) 2000 High Video */
 	DRIVER( cfever1k )	/* (c) 2000 High Video */
 	DRIVER( girotutt )	/* (c) 2000 High Video */

	/* Igrosoft */
	/* Multifish */
	//DRIVER( mfish )   /* (c) 2002 */
	//DRIVER( mfish_2 ) /* (c) 2002 */
	DRIVER( mfish_3 )	/* (c) 2002 */
	DRIVER( mfish_3a )	/* (c) 2002 */
	//DRIVER( mfish_4 ) /* (c) 2002 */
	//DRIVER( mfish_5 ) /* (c) 2002 */
	//DRIVER( mfish_6 ) /* (c) 2002 */
	//DRIVER( mfish_7 ) /* (c) 2002 */
	//DRIVER( mfish_8 ) /* (c) 2002 */
	//DRIVER( mfish_9 ) /* (c) 2002 */
	//DRIVER( mfish_10 )    /* (c) 2002 */
	//DRIVER( mfish_11 )    /* (c) 2002 */
	DRIVER( mfish_12 )	/* (c) 2002 */
	DRIVER( mfish_12a )	/* (c) 2002 */
	//DRIVER( mfish_13 )    /* (c) 2002 */

	/* Crazy Monkey */
	//DRIVER( crzmon )  /* (c) 2003 */
	//DRIVER( crzmon_2 )    /* (c) 2003 */
	//DRIVER( crzmon_3 )    /* (c) 2003 */
	//DRIVER( crzmon_4 )    /* (c) 2003 */
	//DRIVER( crzmon_5 )    /* (c) 2003 */
	//DRIVER( crzmon_6 )
	DRIVER( crzmon_7 )	/* (c) 2003 */
	DRIVER( crzmon_7a )	/* (c) 2003 */
	DRIVER( crzmon_7b )	/* (c) 2003 */
	DRIVER( crzmon_8 )	/* (c) 2003 */
	DRIVER( crzmon_8a )	/* (c) 2003 */

	/* Fruit Cocktail */
	//DRIVER( fcockt )  /* (c) 2003 */
	//DRIVER( fcockt_2 )    /* (c) 2003 */
	//DRIVER( fcockt_3 )    /* (c) 2003 */
	//DRIVER( fcockt_4 )    /* (c) 2003 */
	//DRIVER( fcockt_5 )    /* (c) 2003 */
	DRIVER( fcockt_6 )	/* (c) 2003 */
	DRIVER( fcockt_6a )	/* (c) 2003 */
	DRIVER( fcockt_6b )	/* (c) 2003 */
	DRIVER( fcockt_7 )	/* (c) 2003 */
	DRIVER( fcockt_7a )	/* (c) 2003 */
	DRIVER( fcockt_8 )	/* (c) 2003 */

	/* Lucky Haunter */
	//DRIVER( lhaunt )  /* (c) 2003 */
	//DRIVER( lhaunt_2 )    /* (c) 2003 */
	//DRIVER( lhaunt_3 )    /* (c) 2003 */
	DRIVER( lhaunt_4 )	/* (c) 2003 */
	DRIVER( lhaunt_4a )	/* (c) 2003 */
	DRIVER( lhaunt_5 )	/* (c) 2003 */
	DRIVER( lhaunt_5a )	/* (c) 2003 */
	DRIVER( lhaunt_6 )	/* (c) 2003 */
	DRIVER( lhaunt_6a )	/* (c) 2003 */

	/* Rollfruit */
	//DRIVER( rollfr )  /* (c) 2003 */
	DRIVER( rollfr_2 )	/* (c) 2003 */

	/* Garage */
	//DRIVER( garage )  /* (c) 2004 */
	//DRIVER( garage_2 )    /* (c) 2004 */
	//DRIVER( garage_3 )    /* (c) 2004 */
	DRIVER( garage_4 )	/* (c) 2004 */
	DRIVER( garage_4a )	/* (c) 2004 */
	DRIVER( garage_5 )	/* (c) 2004 */
	DRIVER( garage_5a )	/* (c) 2004 */

	/* Rock Climber */
	//DRIVER( rclimb )  /* (c) 2004 */
	//DRIVER( rclimb_2 )    /* (c) 2004 */
	DRIVER( rclimb_3 )	/* (c) 2004 */
	DRIVER( rclimb_3a )	/* (c) 2004 */
	DRIVER( rclimb_3b )	/* (c) 2004 */

	/* Sweet Life */
	DRIVER( sweetl )	/* (c) 2004 */
	DRIVER( sweetla )	/* (c) 2004 */

	/* Resident */
	//DRIVER( resdnt )  /* (c) 2004 */
	DRIVER( resdnt_2 )	/* (c) 2004 */
	DRIVER( resdnt_2a )	/* (c) 2004 */

	/* Island */
	DRIVER( island )	/* (c) 2005 */
	DRIVER( islanda )	/* (c) 2005 */

	/* Pirate */
	//DRIVER( pirate )  /* (c) 2005 */
	DRIVER( pirate_1 )	/* (c) 2005 */
	//DRIVER( pirate_2 )/* (c) 2005 */

	/* Island 2 */
	DRIVER( island2 )	/* (c) 2006 */
	DRIVER( island2a )	/* (c) 2006 */

	/* Keks */
	DRIVER( keks )		/* (c) 2006 */
	DRIVER( keksa )		/* (c) 2006 */
	DRIVER( keksb )		/* (c) 2006 */
	DRIVER( keks_2 )	/* (c) 2006 */
	DRIVER( keks_2a )	/* (c) 2006 */

	/* Island */
	DRIVER( island )

	/* IGS hardware?*/
	DRIVER( goldstar )	/* (c) 198? IGS */
	DRIVER( goldstbl )	/* (c) 198? IGS */
	DRIVER( moonlght )	/* bootleg */
	DRIVER( chry10 )	/* bootleg */
	DRIVER( chrygld )	/* bootleg */
	DRIVER( kkojnoli )	/* 198? south korean hack */
	DRIVER( ladylinr )	/* (c) 198? TAB Austria */
	DRIVER( mtonic )	/* 198? (c) Tonic */
	DRIVER( wcat3 )
  	DRIVER( cpoker )	/* (c) 1993? IGS */
  	DRIVER( cpokert )	/* (c) 1993? Tuning */
 	DRIVER( csk227it )	/* (c) 198? IGS */
 	DRIVER( csk234it )	/* (c) 198? IGS */
	DRIVER( igs_ncs )	/* (c) 198? IGS */
	DRIVER( igs_ncs2 )	/* (c) 2000 IGS */
	DRIVER( spk116it )	/* (c) 199? IGS */
	DRIVER( jackie )	/* (c) 1993 IGS */
	DRIVER( pktet346 )	/* (c) 199? IGS */
	DRIVER( chleague )	/* (c) 199? IGS */
	DRIVER( chleagul )	/* (c) 199? IGS */
	DRIVER( number10 )	/* (c) IGS (Board labeled Playmark Srl) */
	DRIVER( numbr10l )	/* (c) IGS (Board labeled Playmark Srl) */

	DRIVER( jingbell )	/* (c) 1995? */
	DRIVER( gp98 )		/* (c) 19?? */

	/* IGT */
	DRIVER( drw80pkr )	/* (c) 1983 IGT - International Gaming Technology */
	DRIVER( peset038 )	/* (c) 1987 IGT - International Gaming Technology */
	DRIVER( pepp0043 )	/* (c) 1987 IGT - International Gaming Technology */
	DRIVER( pepp0065 )	/* (c) 1987 IGT - International Gaming Technology */
	DRIVER( pepp0158 )	/* (c) 1987 IGT - International Gaming Technology */
	DRIVER( pepp0188 )	/* (c) 1987 IGT - International Gaming Technology */
	DRIVER( pepp0250 )	/* (c) 1987 IGT - International Gaming Technology */
	DRIVER( pepp0447 )	/* (c) 1987 IGT - International Gaming Technology */
	DRIVER( pepp0516 )	/* (c) 1987 IGT - International Gaming Technology */
	DRIVER( pebe0014 )	/* (c) 1994 IGT - International Gaming Technology */
	DRIVER( peke1012 )	/* (c) 1994 IGT - International Gaming Technology */
	DRIVER( peps0014 )	/* (c) 1996 IGT - International Gaming Technology */
	DRIVER( peps0022 )	/* (c) 1996 IGT - International Gaming Technology */
	DRIVER( peps0043 )	/* (c) 1996 IGT - International Gaming Technology */
	DRIVER( peps0045 )	/* (c) 1996 IGT - International Gaming Technology */
	DRIVER( peps0308 )	/* (c) 1996 IGT - International Gaming Technology */
	DRIVER( peps0615 )	/* (c) 1996 IGT - International Gaming Technology */
	DRIVER( peps0716 )	/* (c) 1996 IGT - International Gaming Technology */
	DRIVER( pex2069p )	/* (c) 1995 IGT - International Gaming Technology */
	DRIVER( pexp0019 )	/* (c) 1995 IGT - International Gaming Technology */
	DRIVER( pexp0112 )	/* (c) 1995 IGT - International Gaming Technology */
	DRIVER( pexs0006 )	/* (c) 1997 IGT - International Gaming Technology */
	DRIVER( pexmp006 )	/* (c) 1997 IGT - International Gaming Technology */
	DRIVER( pexmp017 )	/* (c) 1997 IGT - International Gaming Technology */
	DRIVER( pexmp024 )	/* (c) 1997 IGT - International Gaming Technology */

	/* Impera */
	DRIVER( magicard )	/* (c) 199? */
	DRIVER( magicarda )	/* (c) 199? */
	DRIVER( magicardb )	/* (c) 199? */

	/* Infocube */
	DRIVER( pangofun )	/* (c) 1995 InfoCube */
	
	/* InterFlip / Recreativos Franco */
 	DRIVER( videopkr )	/* (c) 1984 InterFlip */
 	DRIVER( blckjack )	/* (c) 1984 InterFlip */
 	DRIVER( videodad )	/* (c) 1987 InterFlip */
 	DRIVER( videocba )	/* (c) 1987 InterFlip */
	DRIVER( babypkr )	/* (c) 1987 Recreativos Franco */
	DRIVER( babydad )	/* (c) 1987 Recreativos Franco */

	/* JPM Give us a Break hardware */
	DRIVER( guab )		/* (c) 1986 */
	DRIVER( guab3a )	/* (c) 1986 */
	DRIVER( guab4 )		/* (c) 1986 */
	DRIVER( guab6 )		/* (c) 1986 */
	DRIVER( guab6a )	/* (c) 1986 */
	DRIVER( guab7 )		/* (c) 1986 */
	DRIVER( guab21 )	/* (c) 1986 */
	DRIVER( guab43 )	/* (c) 1986 */
	DRIVER( tenup )		/* (c) 1988 */
	DRIVER( tenup3 )	/* (c) 1988 */

	/* JPM System 5 + video expansion 2 Games */
	DRIVER( monopoly )	/* (c) 1994 */
	DRIVER( monoplcl )	/* (c) 1995 */
	DRIVER( monopldx )	/* (c) 1995 */

	/* JPM Impact Games */
	DRIVER( cluedo )	/* (c) 1995 */
	DRIVER( cluedo2c )	/* (c) 1995 */
	DRIVER( cluedo2 )	/* (c) 1995 */
	DRIVER( trivialp )	/* (c) 1996 */
	DRIVER( scrabble )	/* (c) 1997 */
	DRIVER( hngmnjpm )	/* (c) 1998 */
	DRIVER( coronatn )	/* (c) 1999 */

	/* Nazionale Elettronica */
	/* H8/3048 italian gambling games */
	DRIVER( laperla )	/* (c) 2002 Nazionale Elettronica */
	DRIVER( laperlag )	/* (c) 2001 Nazionale Elettronica */
	DRIVER( capunc )	/* (c) 2000 Nazionale Elettronica */
	DRIVER( capcor )	/* (c) 2001 Nazionale Elettronica */
	DRIVER( euro2k2 )	/* (c) 2001 Nazionale Elettronica */
	DRIVER( euro2k2a )	/* (c) 2001 Nazionale Elettronica */
	DRIVER( euro2k2s )	/* (c) 2002 Nazionale Elettronica */
	DRIVER( mnumber )	/* (c) 200? M.M. - B.R.L. */

	/* Nichibutsu */
	DRIVER( jangou )    /* (c) 1983 */
	/* Jangou Night */  /* (c) 1983 */
	DRIVER( jngolady )  /* (c) 1984 */
	DRIVER( cntrygrl )  /* (c) 1984 Royal Denshi */
	DRIVER( 3ds )       /* (c) 1985 */

	/* Novomatic */
	DRIVER( ampoker2 )	/* (c) 1990 Novomatic */
	DRIVER( ampkr2b1 )	/* 1990 bootleg */
	DRIVER( ampkr2b2 )	/* 1990 bootleg */
	DRIVER( ampkr2b3 )	/* 1994 bootleg */
	DRIVER( ampkr2b4 )	/* 1994 bootleg */
	DRIVER( ampkr228 )	/* 1990 bootleg */
	DRIVER( pkrdewin )	/* 1990 bootleg */
	DRIVER( ampkr95 )	/* 1995 bootleg */
	DRIVER( videomat )	/* 1990 bootleg */
	DRIVER( rabbitpk )	/* 1990 bootleg */

	/* P&A Games */
	DRIVER( magicfly )	/* (c) 198? P&A GAMES */
	
	/* Playmark */
	DRIVER( hotmind )	/* (c) 1995 */
	DRIVER( hotminda )	/* (c) 1995 */
	DRIVER( sderby )	/* (c) 1996 Playmark */
	DRIVER( spacewin )	/* (c) 1997 Playmark */
	DRIVER( pmroulet )	/* (c) 1997 Playmark */
	DRIVER( magicstk )	/* (c) 1997 Playmark */

	/* Prince Co.*/
	DRIVER( spotty )	/* (c) 2001 Prince Co. */
		
	/* Sega */
	/* Bingo-based games */
	DRIVER( bingoc )    /* (c) 1989 Sega */
	/* Bingo Fantasy  *//* (c) 19?? Sega */
	/* Bingo Star     *//* (c) 19?? Sega */
	/* Bingo Party    *//* (c) 1993 Sega */
	/* BP Phoenix     *//* (c) 1998 Sega */
	/* BP Special     *//* (c) 2000 Sega */
	/* BP Multicards  *//* (c) 2002 Sega */
	/* BP Splash      *//* (c) 2002 Sega */
	/* Bingo Planet   *//* (c) 1997 Sega */

	DRIVER( witch )		/* (c) 1992 Sega / Vic Tokai / Excellent Systems */

	/* SGS */
	DRIVER( cpokerpk )	/* (c) SGS (bootleg blue board) */
	DRIVER( cpokerpkg )	/* (c) SGS (bootleg green board) */
	DRIVER( citalcup )	/* (c) SGS (bootleg of IGS v220it) */

	/* Sigma */
	DRIVER( luctoday )	/* (c) 1980 Sigma */
	DRIVER( chewing )	/* Unknown */
	DRIVER( jokrwild )	/* (c) 1988 Sigma */

	DRIVER( sigmapkr )	/* (c) 1995 Sigma */
	DRIVER( sigma2k )	/* (c) 2000 Sigma */

	/* SMS */
	DRIVER( trvhang )	/* (c) 1984 SMS MFG CORP */
	DRIVER( trvhanga )	/* (c) 1984 SMS MFG CORP */
	DRIVER( sureshot )	/* (c) 1985 SMS MFG CORP */

	/* Status */
	DRIVER( statusbj )	/* (c) 1981 Status Games */

	/* Subsino */
	DRIVER( victor5 )	/* (c) 1990 Subsino */
	DRIVER( victor21 )	/* (c) 1990 Subsino */
	DRIVER( crsbingo )	/* (c) 1991 Subsino */
	DRIVER( sharkpy )	/* (c) 1993 Subsino */
	DRIVER( sharkpya )	/* (c) 1993 Subsino */
	DRIVER( smoto20 )	/* (c) 1996 Subsino */
	DRIVER( smoto16 )	/* (c) 1996 Subsino */

	/* STG? */
	DRIVER( queen )

	/* Sure games */
	DRIVER( mil4000 )	/* (c) 2000 Sure Milano */
	DRIVER( mil4000a )	/* (c) 2000 Sure Milano */
	DRIVER( mil4000b )	/* (c) 2000 Sure Milano */
	DRIVER( mil4000c )	/* (c) 2000 Sure Milano */

	/* Taito */
	DRIVER( cchance )   /* (c)1987 Taito? */

	/* Tatsumi */
	DRIVER( kingdrby )  /* (c) 1981 Tatsumi */
	/* Tazmi */
	DRIVER( cowrace )	/* (c) 20?? hack */
	
	/* Tehkan */
	DRIVER( lvcards )	/* (c) 1985 Tehkan */
	DRIVER( lvpoker )	/* (c) 1985 Tehkan */
	DRIVER( ponttehk )	/* (c) 1985 Tehkan */

	/* Veltmeijer Automaten */
	DRIVER( cardline )	/* (c) 199? Veltmeijer */
	DRIVER( pbchmp95 )	/* (c) 1995 Veltmeijer Automaten */

	/* Wing */
	DRIVER( slotcarn )	/* (c) 1985 Wing Co. Ltd */
	DRIVER( lucky74 )	/* (c) 1988 Wing Co. Ltd */
	DRIVER( lucky74a )	/* (c) 1988 Wing Co. Ltd */
	DRIVER( lucky8 )	/* (c) 1989 Wing Co. Ltd */
	DRIVER( lucky8a )	/* (c) 1989 Wing Co. Ltd */
	DRIVER( luckgrln )	/* (c) 1991 Wing Co. Ltd */

	/* World Game */
	DRIVER( vroulet )	/* (c) 1989 World Game */

	/* Zilec - Zenitone */
	DRIVER( merlinmm )  /* (c) 1986 Zilec-Zenitone */
	DRIVER( cashquiz )	/* (c) 1986 Zilec-Zenitone */

	/* Unknown hardware */
	DRIVER( 7mezzo )	/* (c) 198? Unknown */
	DRIVER( big10 )		/* 198? Unknown */
	
	DRIVER( bingor1 )	/* (c) 198? Unknown */
	DRIVER( bingor2 )	/* (c) 198? Unknown */
	DRIVER( bingor3 )	/* (c) 198? Unknown */
	DRIVER( bingor4 )	/* (c) 198? Unknown */

	DRIVER( fortecar )
	DRIVER( murogem )	/* ??? */
	DRIVER( murogema )	/* ??? */
	DRIVER( murogmbl )	/* ??? */
	DRIVER( lasvegas )	/* hack */


	DRIVER( skill98 )	/* (c) 1998 Amcoe */
	DRIVER( match98 )	/* (c) 1998 Amcoe */
	DRIVER( schery97 )	/* (c) 1998 Amcoe */
	DRIVER( schery97a )	/* (c) 1998 Amcoe */
	DRIVER( roypok96 )	/* (c) 1996 Amcoe */
	DRIVER( roypok96a )	/* (c) 1996 Amcoe */
	DRIVER( roypok96b )	/* (c) 1996 Amcoe */
	DRIVER( pokonl97 )	/* (c) 1997 Amcoe */
	DRIVER( nc96 )		/* (c) 1996 Amcoe */
	DRIVER( nc96a )		/* (c) 1996 Amcoe */
	DRIVER( nc96b )		/* (c) 1996 Amcoe */
	DRIVER( nc96c )		/* (c) 1996 Amcoe */
	DRIVER( nc96txt )	/* (c) 2000 Amcoe */

	DRIVER( kkojnoli )	/* 198? south korean hack */
	DRIVER( mtonic )	/* 198? (c) Tonic */

	DRIVER( chsuper3 )	/* unknown */
	DRIVER( chsuper2 )	/* unknown */
	DRIVER( 3super8 )	/* unknown */
	DRIVER( buster )	/* (c) 1987 Marian Electronics Ltd. */
	DRIVER( spielbud )	/* (c) 1985 ADP */

	DRIVER( carb2002 )	/* bootleg */
	DRIVER( carb2003 )	/* bootleg */


	/* H8/3337 italian gambling games */
	DRIVER( ntcash )	/* (c) 1999 unknown */
	DRIVER( wizard )	/* (c) 1999 A.A. */
	DRIVER( trstar2k )	/* (c) 1999 A.M. */
	DRIVER( laser2k1 )	/* (c) 2001 unknown */
	DRIVER( mdrink )	/* (c) 2001 unknown */
	DRIVER( te0144 )	/* (c) 2001 unknown */
	DRIVER( cmagica )	/* (c) 200? unknown */
	DRIVER( millsun )	/* (c) 200? unknown */
	DRIVER( sspac2k1 )	/* (c) 200? unknown */
	DRIVER( elvis )		/* (c) 200? unknown */
	DRIVER( sstar )		/* (c) 200? unknown */
	DRIVER( pirati )	/* (c) 2001 Cin */

	/* Intel 8086-based italian gambling games */
	DRIVER( newmcard )	/* (c) 19?? unknown */
	DRIVER( brasil )	/* (c) 2000 unknown */
	DRIVER( fashion )	/* (c) 2000 unknown */
	DRIVER( ciclone )   /* (c) 2000 unknown */

	/* M68k-based gambling games */
	DRIVER( steaser )	/* (c) 1993 unknown */
	DRIVER( ilpag )		/* (c) 199? unknown */

	
	/* Mitsubishi/Renesas M16/62A italian gambling games */
	DRIVER( ejollyx5 )	/* (c) 200? Solar Games */
	DRIVER( grandprx )	/* (c) 200? 4fun */
	DRIVER( supjolly )	/* (c) 200? unknown */

	/* Bootlegs */
	DRIVER( darkhors )	/* (c) 2001 bootleg of Jockey Club II */
	DRIVER( stellecu )	/* (c) 1998 */

	DRIVER( 4roses )	/* 1999 Unknown */
	DRIVER( 4rosesa )	/* 1999 Unknown */

	/* Hi-Lo Poker-based */
	DRIVER( gtipoker )	/* (c) 1983 GTI Inc */
	DRIVER( norautp )	/* (c) 1988? Noraut */
	DRIVER( norautjp )	/* (c) 1988? Noraut */
	DRIVER( norautrh )	/* (c) 1988? Noraut Ltd */
	DRIVER( norautu )	/* (c) 1988? Noraut Ltd */
	DRIVER( norautv3 )	/* (c) 1988? Noraut Ltd */
	DRIVER( norautpn )	/* (c) 1990? unknown */
	
/* Drivers below are mechanical games, usually with no video display, requiring external artwork to function.
       These are currently mostly 'fruit machine' style games, although this may later be extended to system logic
       emulation for pinball machiens.

       the m_ prefix is used to identify them as many have very generic names.

    */

	/* Scorpion 2 */
	DRIVER( m_brkfst )

	DRIVER( m_bdrwho )
	DRIVER( m_bdrwh1 )
	DRIVER( m_bdrwh2 )
	DRIVER( m_bdrwh3 )
	DRIVER( m_bdrwh4 )
	DRIVER( m_bdrwh5 )
	DRIVER( m_bdrwh6 )
	DRIVER( m_bdrwh7 )
	DRIVER( m_bdrwh8 )
	DRIVER( m_bdrwh9 )
	DRIVER( m_bdrw10 )
	DRIVER( m_bdrw11 )
	DRIVER( m_bdrw12 )
	DRIVER( m_bdrw13 )
	DRIVER( m_bdrw14 )
	DRIVER( m_bdrw15 )
	DRIVER( m_bdrw16 )
	DRIVER( m_bdrw17 )

	DRIVER( m_bfocus )
	DRIVER( m_bcgslm )
	DRIVER( m_luvjub )
	DRIVER( m_cpeno1 )

	/* System85 games */
	DRIVER( m_supcrd )	/* (c) 198? BFM */

	/* JPM Impact games */
	DRIVER( m_tbirds )

	/* Scorpion1 games */
	DRIVER( m_lotsse )	/* (c) 198? BFM Dutch ROMS, prelim*/
	DRIVER( m_roulet )	/* (c) 198? BFM Dutch ROMS, prelim*/
	DRIVER( m_clattr )	/* (c) 1990 BFM,     Game Card 39-370-196*/
	DRIVER( m_tppokr )	/* (c) 1996 BFM/ELAM,Game Card 95-750-899, uses Adder board for feature gfx*/

	/* Maygay Machines Ltd. */
	DRIVER( m_sptlgt )

	DRIVER( screenpl )
	DRIVER( screenp1 )
	DRIVER( screenp2 )

	/* MPU4 */
	DRIVER( m_oldtmr )	/* Barcrest - highly prelim*/
	DRIVER( m_ccelbr )
	DRIVER( m_gmball )

	/* MPU5 */
	DRIVER( m_honmon )

	/* Leisure Ent. */
	DRIVER( roul )		/* (c) 1990 */

	/* Accept LTD. */
	DRIVER( hitpoker )	/* (c) 1997 */

	/* Videotronics */
	DRIVER( vpoker )	/* (c) 198? */

#endif	/* DRIVER_RECURSIVE */
