/***************************************************************************

    Maygay M2 hardware

    preliminary driver by Phil Bennett

    Games supported:
        * Aladdin's Cave
        * Big Break
        * Guinness Book of Records
        * London Underground
        * Risk

    Other games on this hardware:
        * Super Clue

 
    Initially:

    000000 - 00ffff  : 128k*2 ROM
    100000 - ??????  : 128k*2 ROM

    After config:

    000000 - 00ffff  : SRAM (Writes vectors here)
    100000 - 13ffff  : 128k*2 ROM

       80000 - 8???? : DRAM

	CS2 = PIC 16C /CS   


***************************************************************************/

#include "driver.h"
#include "cpu/m68000/m68000.h"
//#include "cpu/m68000/m68306.h"
#include "cpu/pic16c5x/pic16c5x.h"
//#include "sound/msm6650.h"
#include "deprecat.h"	// naughty!

#include "debugger.h"

/*************************************
 *
 *  Defines
 *
 *************************************/


/*************************************
 *
 *  Globals
 *
 *************************************/
//UINT16 *vram;
UINT8 *vram;
UINT8 m68k_to_snd_pic;
UINT8 snd_pic_to_m68k;
int data_valid;

extern READ16_HANDLER( gd5429_r );
extern WRITE16_HANDLER( gd5429_w );
extern VIDEO_START( maygaym2 );
extern VIDEO_UPDATE( maygaym2 );


static READ16_HANDLER( vram_r )
{
	offset <<= 1;

	return (vram[offset] << 8) | vram[offset + 1];
}

static WRITE16_HANDLER( vram_w )
{
	offset <<= 1;

	if (ACCESSING_BITS_8_15)
		vram[offset] = data >> 8;

	if (ACCESSING_BITS_0_7)
		vram[offset + 1] = data & 0xff;

}

static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 16 )
//	AM_RANGE(0x000000, 0x000fff) AM_ROM
//	AM_RANGE(0x100000, 0x1fffff) AM_ROM

	AM_RANGE(0x2f0000, 0x2fffff) AM_READWRITE(gd5429_r, gd5429_w)
	AM_RANGE(0x300000, 0x3fffff) AM_READWRITE(vram_r, vram_w)// AM_BASE(&vram)		// Display RAM

	AM_RANGE(0x400000, 0x4fffff) AM_ROM // Bank 1
	AM_RANGE(0x500000, 0x5fffff) AM_ROM // Bank 2
	AM_RANGE(0x600000, 0x6fffff) AM_ROM // Bank 3
	AM_RANGE(0x700000, 0x7fffff) AM_ROM // Bank 4
	AM_RANGE(0x800000, 0x8fffff) AM_ROM // Bank 5
	AM_RANGE(0x900000, 0x9fffff) AM_ROM // Bank 6
ADDRESS_MAP_END


/*
    Sound PIC16C55
*/
static READ8_HANDLER( PIC16C5X_T0_clk_r )
{
	return 0;
}

static READ8_HANDLER( pic16c55_port_a_r )
{
	return 0;
}

static READ8_HANDLER( pic16c55_port_b_r )
{
	if ( !BIT(cpunum_get_info_int(1, CPUINFO_INT_REGISTER + PIC16C5x_PRTC), 6) )
	{
//		printf("PIC reads %x from 68k\n", m68k_to_snd_pic);
		data_valid = 0; // ????
		return m68k_to_snd_pic;
	}
	else
		return 0xff;
}

static READ8_HANDLER( pic16c55_port_c_r )
{
	return data_valid | msm6650_get_busy(0);
}

/*


RA0 = OKI SI (clock)
RA1 = OKI SD
RA2 = M62405P SCL
RA3 = M62405P SDA

RB0 - RB1: Data bus



RC0 = OKI /BUSY
RC1 = OKI NAR
RC2 = OKI /ST
RC3 = OKI /CHANNEL
RC4 = PIN 6 of GAL (something volume control relatd)
RC5 = 68k IRQ1
RC6 = U8 /OC (for reading 68k data)
RC7 = U11 CLK (for writing 68k)



GAL 1
GAL 2
GAL 3
GAL 4
GAL 5
GAL 6 -> PIC RC4
GAL 7 -> M62405P RESET
GAL 8 -> PIN 24 U3 ROM
GAL 9 -> PIN 24 U2 ROM
GAL 10

GAL 12 -> OKI /CE
GAL 13 <- RA19
GAL 14 VCC
GAL 15
GAL 16
GAL 17
GAL 18
GAL 19 <- PIC RC6
GAL 20



*/
static WRITE8_HANDLER( pic16c55_port_a_w )
{
//	printf("A: %x\n", data);



	int clock, new_data;
	static int old_clock = 0;
	static int old_data = 0;
	static int started = 0;

	static int shift = 0;

	msm6650_data_w(0, data & 2);
	msm6650_clk_w(0, data & 1);

	clock = data & 4;
	new_data = (data & 8) >> 3;

	if (started)
	{
		// Rising edge
    	if (!old_clock && clock)
		{
			shift = (shift << 1) | new_data;
   		}

	}

	if (!started && (clock && (old_data && !new_data)))
	{
		shift = 0;
		started = 1;
//		printf("M6240P Serial Start\n");
 	}

	if (started && (clock && (!old_data && new_data)))
	{
		int i;
//		printf("M6240P Serial End\n");

		for (i = 27; i >= 0; i--)
		{
//			if (i ==
//			printf("%x", (shift >> i) & 1);
		}

		started = 0;
	}

	old_clock = clock;
	old_data = new_data;
}


// TODO : Need to implenment latch functionality
static WRITE8_HANDLER( pic16c55_port_b_w )
{
//	printf("B: %x\n", data);
}

// ?
static WRITE8_HANDLER( pic16c55_port_c_w )
{
	static UINT8 portc_prev = 0;     // Save state!

	msm6650_set_st(0, data & 4);
	msm6650_set_ch(0, data & 8);

//	printf("C: %x\n", data);

/*
	0110
	1110

	B WRITE
    0110   6C
    1110   EC
    1000   8C	<-- Interrupt?

    0100
    1100

	1100
	1100
	1110

    B TRIS
    1100   CC
    1000   8C
	READ
    1100   CC
							*/

	/* Clock data on PORTB pins into U11 register */
	if (!BIT(portc_prev, 7) && BIT(data, 7))
	{
		snd_pic_to_m68k = cpunum_get_info_int(1, CPUINFO_INT_REGISTER + PIC16C5x_PRTB);;
//		printf("PIC posts: %x to 68k\n", snd_pic_to_m68k);
	}

	/* Only handle change of interrupt line state */
	if ( BIT((portc_prev ^ data), 5) )
	{
		cpunum_set_input_line(machine, 0, 1, BIT(data, 5) ? ASSERT_LINE : CLEAR_LINE);
//		printf("68k interupted\n");
		cpu_boost_interleave(attotime_zero, ATTOTIME_IN_USEC(100));
	}

	portc_prev = data;
}

static ADDRESS_MAP_START( sound_io_map, ADDRESS_SPACE_IO, 8 )
	AM_RANGE(0x00, 0x00) AM_READWRITE(pic16c55_port_a_r, pic16c55_port_a_w)
	AM_RANGE(0x01, 0x01) AM_READWRITE(pic16c55_port_b_r, pic16c55_port_b_w)
	AM_RANGE(0x02, 0x02) AM_READWRITE(pic16c55_port_c_r, pic16c55_port_c_w)
	AM_RANGE(PIC16C5x_T0, PIC16C5x_T0) AM_READ(PIC16C5X_T0_clk_r)
ADDRESS_MAP_END


/*************************************
 *
 *  Port definitions
 *
 *************************************/

static INPUT_PORTS_START( risk )
PORT_START
	PORT_DIPNAME( 0x01, 0x01, "DSW01")
	PORT_DIPSETTING(	0x01, DEF_STR( Off ) )
	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x02, 0x02, "DSW02")
	PORT_DIPSETTING(	0x02, DEF_STR( Off ) )
	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x04, 0x04, "DSW03")
	PORT_DIPSETTING(	0x04, DEF_STR( Off ) )
	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x08, 0x08, "DSW04")
	PORT_DIPSETTING(	0x08, DEF_STR( Off ) )
	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x10, 0x10, "Stake selection?")
	PORT_DIPSETTING(	0x10, "5p" )
	PORT_DIPSETTING(	0x00, "10p" )
	PORT_DIPNAME( 0x20, 0x20, "DSW06")
	PORT_DIPSETTING(	0x20, DEF_STR( Off ) )
	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x40, 0x40, "DSW07")
	PORT_DIPSETTING(	0x40, DEF_STR( Off ) )
	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x80, 0x80, "DSW08")
	PORT_DIPSETTING(	0x80, DEF_STR( Off ) )
	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
INPUT_PORTS_END

/*************************************
 *
 *  Machine driver
 *
 *************************************/

UINT16 *sram;
UINT16 *dram;

// Need to sort this out!
READ16_HANDLER( maygaym2_rom_r )
{
	UINT16 *rom = (UINT16*)memory_region("main");
//	offset &= 0x1ffff;
	return rom[offset];
}


// Offset masks!
READ16_HANDLER( maygaym2_io_pic_r )
{
//	return 0x80;// mame_rand(machine);
	return 0x80;
}

WRITE16_HANDLER( maygaym2_io_pic_w )
{
//	printf("PIC W:%x\n", data);
//	DEBUGGER_BREAK;
}

		#include "debugger.h"
// Offset masks!
// FFFE0001

READ16_HANDLER( maygaym2_snd_pic_r )
{
//	printf("68k reads %x from PIC\n", snd_pic_to_m68k);
//	DEBUGGER_BREAK;
	return snd_pic_to_m68k;//mame_rand(machine);
}

WRITE16_HANDLER( maygaym2_snd_pic_w )
{
//	printf("68k writes %x to PIC\n", data);
	m68k_to_snd_pic = data & 0xff;
	data_valid = 0x10;
	cpu_boost_interleave(attotime_zero, ATTOTIME_IN_USEC(100));
//	DEBUGGER_BREAK;
}


// Offset masks!
READ16_HANDLER( maygaym2_sram_r )
{
	return sram[offset];
}

WRITE16_HANDLER( maygaym2_sram_w )
{
	COMBINE_DATA(&sram[offset]);
}


// Offset masks!
READ16_HANDLER( maygaym2_dram_r )
{
	return dram[offset];
}

WRITE16_HANDLER( maygaym2_dram_w )
{
	COMBINE_DATA(&dram[offset]);
}

static OPBASE_HANDLER( cps3_opbase_handler )
{
	opbase->rom = opbase->ram = memory_region("main");
	return ~0;
}

static MACHINE_START( maygaym2 )
{
	m68306_set_cs_handlers(0, &maygaym2_rom_r, NULL);
	m68306_set_cs_handlers(1, &maygaym2_sram_r, &maygaym2_sram_w );
	m68306_set_cs_handlers(2, &maygaym2_io_pic_r, &maygaym2_io_pic_w );
	m68306_set_cs_handlers(3, &maygaym2_snd_pic_r, &maygaym2_snd_pic_w );

	m68306_set_dram_handlers(0, &maygaym2_dram_r, &maygaym2_dram_w );

	sram = auto_malloc(0x4000);
	dram = auto_malloc(0x80000);
	vram = auto_malloc(0x100000);

	state_save_register_global_pointer(dram, 0x80000/2);
	state_save_register_global_pointer(sram, 0x4000/2);
	state_save_register_global_pointer(vram, 0x100000);

	memory_set_opbase_handler(0, cps3_opbase_handler);
}

static MACHINE_RESET( maygaym2 )
{

}

static NVRAM_HANDLER( maygaym2 )
{
	if (read_or_write)
		mame_fwrite(file, sram, 0x4000);
	else if (file)
		mame_fread(file, sram, 0x4000);
	else
		memset(sram, 0xff, 0x4000);
}


/*************************************
 *
 *  Sound definitions
 *
 *************************************/




static MACHINE_DRIVER_START( maygaym2 )
	MDRV_CPU_ADD("maincpu", M68306, 16000000)
	MDRV_CPU_PROGRAM_MAP(main_map, 0)
//	MDRV_CPU_VBLANK_INT("main", irq4_line_hold)			// TODO

//	MDRV_CPU_ADD(PIC16C55, 4000000)  // dummy
//	MDRV_CPU_IO_MAP(io_io_map, 0)

	MDRV_CPU_ADD("soundpic",PIC16C55, 4000000)
	MDRV_CPU_IO_MAP(sound_io_map, 0)

	MDRV_MACHINE_START( maygaym2 )
	MDRV_MACHINE_RESET( maygaym2 )

	MDRV_NVRAM_HANDLER( maygaym2 )

//	MDRV_INTERLEAVE(500)

	MDRV_SCREEN_ADD("screen", RASTER)
	MDRV_SCREEN_REFRESH_RATE(60)
	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500))	// TODO
	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
	MDRV_SCREEN_SIZE(640, 240)
	MDRV_SCREEN_VISIBLE_AREA(0, 640-1, 0, 240-1)

	MDRV_PALETTE_LENGTH(256)

	MDRV_VIDEO_START(maygaym2)
	MDRV_VIDEO_UPDATE(maygaym2)

	/* Sound hardware */
	MDRV_SPEAKER_STANDARD_MONO("mono")   // ?

	MDRV_SOUND_ADD("msm6650", MSM6650, 4000000)
	MDRV_SOUND_CONFIG(msm6650_interface_serial) // does it matter?
	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
MACHINE_DRIVER_END


/*************************************
 *
 *  ROM definition(s)
 *
 *************************************/
ROM_START( risk )
	ROM_REGION( 0x4000000, "maincpu", 0 ) // that's huge!
	ROM_LOAD16_BYTE( "u28_std.u28", 0x00000,  0x20000, CRC(71b0e758) SHA1(d84696b2a5d2e3e9afc8fc5037481b6cb162d7b7) )
	ROM_RELOAD(                  	0x100000, 0x20000 )

	ROM_LOAD16_BYTE( "u27_std.u27", 0x00001,  0x20000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_RELOAD(                  	0x100001, 0x20000 )

	/* Bank 1 */
	ROM_LOAD16_BYTE( "dg7-001-4-u07.u7",  0x400000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "dg7-001-4-u01.u1",  0x400001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 2 */
	ROM_LOAD16_BYTE( "dg7-001-4-u08.u8",  0x500000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "dg7-001-4-u02.u2",  0x500001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 3 */
	ROM_LOAD16_BYTE( "dg7-001-4-u09.u9",  0x600000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "dg7-001-4-u03.u3",  0x600001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 4 */
	ROM_LOAD16_BYTE( "dg7-001-4-u10.u10", 0x700000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "dg7-001-4-u04.u4",  0x700001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 5 */
	ROM_FILL(                             0x800000, 0x100000, 0xff )

	/* Bank 6 */
	ROM_LOAD16_BYTE( "dg7-001-4-u12.u12", 0x900000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "dg7-001-4-u06.u6",  0x900001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	ROM_REGION( 0x4000, "soundpic", 0 )
	ROM_LOAD( "pic16c55.u5", 0x00000, 0x4000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	ROM_REGION( 0x100000, "MSM6650", 0 )
	ROM_LOAD( "d1g1-145.u3", 0x00000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD( "d1g1-145.u2", 0x80000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
ROM_END

ROM_START( aladdins )
	ROM_REGION( 0x4000000, "maincpu", 0 ) // check
	ROM_LOAD16_BYTE( "sw7-536s.u28", 0x00000, 0x20000, CRC(5dfe53fa) SHA1(6b71ae36204bdde8354e78c9ecbc4c35f46bd529) )
	ROM_RELOAD(                  	0x100000, 0x20000 )

	ROM_LOAD16_BYTE( "sw7-536s.u27", 0x00001, 0x20000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_RELOAD(                  	0x100001, 0x20000 )

	/* Bank 1 */
	ROM_LOAD16_BYTE( "dg-001-4-u07.u7",  0x400000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "dg-001-4-u01.u1",  0x400001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 2 */
	ROM_LOAD16_BYTE( "dg-001-4-u08.u8",  0x500000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "dg-001-4-u02.u2",  0x500001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 3 */
	ROM_FILL(                            0x600000, 0x100000, 0xff )

	/* Bank 4 */
	ROM_FILL(                            0x700000, 0x100000, 0xff )

	/* Bank 5 */
	ROM_FILL(                            0x800000, 0x100000, 0xff )

	/* Bank 6 */
	ROM_LOAD16_BYTE( "dq-003-4-u12.u12", 0x900000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "dq-003-4-u06.u6",  0x900001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	ROM_REGION( 0x4000, "soundpic", 0 )
	ROM_LOAD( "pic16c55.u5", 0x00000, 0x4000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	ROM_REGION( 0x100000, "MSM6650", 0 )
	ROM_LOAD( "d1g1-144.u3", 0x00000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
ROM_END


ROM_START( guinness )
	ROM_REGION( 0x4000000, "maincpu", 0 ) // check
	ROM_LOAD16_BYTE( "std951d.u28", 0x00000, 0x20000, CRC(71b0e758) SHA1(d84696b2a5d2e3e9afc8fc5037481b6cb162d7b7) )
	ROM_RELOAD(                  	0x100000, 0x20000 )

	ROM_LOAD16_BYTE( "std961d.u27", 0x00001, 0x20000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_RELOAD(                  	0x100001, 0x20000 )

	/* Bank 1 */
	ROM_LOAD16_BYTE( "dg70014.u07",  0x400000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "dg70014.u01",  0x400001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 2 */
	ROM_LOAD16_BYTE( "dg70014.u08",  0x500000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "dg70014.u02",  0x500001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 3 */
	ROM_LOAD16_BYTE( "dg70014.u09",  0x600000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "dg70014.u03",  0x600001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 4 */
	ROM_LOAD16_BYTE( "dg70014.u10",  0x700000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "dg70014.u04",  0x700001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 5 */
	ROM_LOAD16_BYTE( "da70014.u11",  0x800000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "da70014.u05",  0x800001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 6 */
	ROM_LOAD16_BYTE( "dq70014.u12", 0x900000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "dq70014.u06",  0x900001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	ROM_REGION( 0x4000, "soundpic", 0 )
	ROM_LOAD( "pic16c55.u5", 0x00000, 0x4000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	ROM_REGION( 0x100000, "MSM6650", 0 )
	ROM_LOAD( "dig1127.u3", 0x00000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD( "dig1127.u2", 0x80000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
ROM_END


ROM_START( londonun )
	ROM_REGION( 0x4000000, "maincpu", 0 ) // check
	ROM_LOAD16_BYTE( "vc_u28.bin", 0x00000, 0x20000, CRC(71b0e758) SHA1(d84696b2a5d2e3e9afc8fc5037481b6cb162d7b7) )
	ROM_RELOAD(                  	0x100000, 0x20000 )

	ROM_LOAD16_BYTE( "vc_u27.bin", 0x00001, 0x20000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_RELOAD(                  	0x100001, 0x20000 )

	/* Bank 1 */
	ROM_LOAD16_BYTE( "vmb_u7.bin",  0x400000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "vmb_u1.bin",  0x400001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 2 */
	ROM_LOAD16_BYTE( "vmb_u8.bin",  0x500000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "vmb_u2.bin",  0x500001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 3 */
	ROM_LOAD16_BYTE( "vmb_u9.bin",  0x600000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "vmb_u3.bin",  0x600001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 4 */
	ROM_LOAD16_BYTE( "vmb_u10.bin", 0x700000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "vmb_u4.bin",  0x700001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 5 */
	ROM_FILL(                       0x800000, 0x100000, 0xff )

	/* Bank 6 */
	ROM_LOAD16_BYTE( "vmb_u12.bin", 0x900000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "vmb_u6.bin",  0x900001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	ROM_REGION( 0x4000, "soundpic", 0 )
	ROM_LOAD( "pic16c55.u5", 0x00000, 0x4000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	ROM_REGION( 0x100000, "MSM6650", 0 )
	ROM_LOAD( "msb_u3.bin", 0x00000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD( "msb_u2.bin", 0x80000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
ROM_END


// 656uxx  SW6-656: Version 1.5
// u28gfd: SW6-618 (version 1.3)

ROM_START( bigbreak )
	ROM_REGION( 0x4000000, "maincpu", 0 ) // check
	ROM_LOAD16_BYTE( "u28gfdbsa6-618std.bin", 0x00000, 0x20000, CRC(71b0e758) SHA1(d84696b2a5d2e3e9afc8fc5037481b6cb162d7b7) )
//	ROM_LOAD16_BYTE( "656u28", 0x00000, 0x20000, CRC(71b0e758) SHA1(d84696b2a5d2e3e9afc8fc5037481b6cb162d7b7) )
	ROM_RELOAD(                  	0x100000, 0x20000 )

	ROM_LOAD16_BYTE( "u27603asw6-618.bin", 0x00001, 0x20000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
//	ROM_LOAD16_BYTE( "657u27", 0x00001, 0x20000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_RELOAD(                  	0x100001, 0x20000 )

	/* Bank 1 */
	ROM_LOAD16_BYTE( "dg6-001-4-u07.bin",  0x400000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "dg6-001-4-u01.bin",  0x400001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 2 */
	ROM_LOAD16_BYTE( "dg6-001-4-u08.bin",  0x500000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "dg6-001-4-u02.bin",  0x500001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 3 */
	ROM_LOAD16_BYTE( "dg6-001-4-u09.bin",  0x600000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "dg6-001-4-u03.bin",  0x600001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 4 */
	ROM_LOAD16_BYTE( "da6-001-4-u10.bin",  0x700000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "da8-001-4-u04.bin",  0x700001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	/* Bank 5 */
	ROM_FILL(                       0x800000, 0x100000, 0xff )

	/* Bank 6 */
	ROM_LOAD16_BYTE( "dq6-001-4-u12.bin", 0x900000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
	ROM_LOAD16_BYTE( "dq6-001-4-u06.bin",  0x900001, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	ROM_REGION( 0x4000, "soundpic", 0 )
	ROM_LOAD( "pic16c55.u5", 0x00000, 0x4000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )

	ROM_REGION( 0x100000, "MSM6650", 0 )
	ROM_LOAD( "soundv3dig1-106.bin", 0x00000, 0x80000, CRC(0f16ec39) SHA1(3eef3563b0c23bd70f8e8cd24fe8cad771e98b4e) )
ROM_END


/*************************************
 *
 *  Game driver(s)
 *
 *************************************/

GAME( 1996, bigbreak, 0, maygaym2, risk, 0, ROT0, "Maygay", "Big Break",                0 )
GAME( 1997, guinness, 0, maygaym2, risk, 0, ROT0, "Maygay", "Guinness Book of Records", 0 )
GAME( 1997, aladdins, 0, maygaym2, risk, 0, ROT0, "Maygay", "Aladdin's Cave",           0 )
GAME( 1997, risk,     0, maygaym2, risk, 0, ROT0, "Maygay", "Risk",                     0 )
GAME( 1997, londonun, 0, maygaym2, risk, 0, ROT0, "Maygay", "London Underground",       0 )

