#include "driver.h"
#include "machine/6821pia.h"
#include "machine/6840ptm.h"

#include "timer.h"
#include "cpu/m6809/m6809.h"
#include "machine/steppers.h"
#include "machine/roc10937.h"
#include "machine/meters.h"

#ifndef AWP_VIDEO /*Defined for fruit machines with mechanical reels*/
#define draw_reel(x)
#else
#define draw_reel(x) awp_draw_reel x
#endif
#include "mpu4.lh"

#define MPU3_MASTER_CLOCK (6880000)

static int	  input_strobe;
static int	  decoder_A0;
static int	  decoder_A1;
static int	  decoder_A2;
static int	  lamp_strobe;
static int	  ic4_triac;
static int	  ic5_triac;


const struct stepper_interface barcrest_mpu3_reel_interface = 
{ 
	BARCREST_48STEP_REEL,
	92,
	2,
	0x00
};

static void triac_update(void)
{
	int i;
	for (i = 0; i < 8; i++)
		if ( data & (1 << i) )		output_set_indexed_value("triac", i, data & (1 << i)); //need cb2 of next 2 pias
}

static READ8_HANDLER( pia_ic3_porta_r )
{
	return input_port_read(machine, input_strobe);
}

static WRITE8_HANDLER( pia_ic3_portb_w )
{
	LOG_IC8(("%04x IC3 PIA Port B Set to %2x (OUTPUT PORT, TRIACS)\n", activecpu_get_previouspc(),data));
}

static WRITE8_HANDLER( pia_ic3_ca2_w )
{
	LOG_IC8(("%04x IC3 PIA write CA2 (input_strobe bit 0 / LED A) %02X\n", activecpu_get_previouspc(), data & 0xFF));

	decoder_A0 = data;
	decoder_update();
}

static const pia6821_interface pia_ic3_intf =
{
	/*inputs : A/B,CA/B1,CA/B2 */ pia_ic3_porta_r, 0, 0, 0, 0, 0,
	/*outputs: A/B,CA/B2       */ 0, pia_ic3_portb_w, pia_ic3_ca2_w, 0,
	/*irqs   : A/B             */ 0,0
};


static WRITE8_HANDLER( pia_ic4_porta_w )
{
	int meter;
	UINT64 cycles  = cpu_get_total_cycles(space->cpu);

/* The meters are connected to a voltage drop sensor, where current
flowing through them also passes through pin B7, meaning that when
any meter is activated, pin B7 goes high.
As for why they connected this to an output port rather than using
CB1, no idea.
This appears to have confounded the schematic drawer, who has assumed that
all eight meters are driven from this port, giving the 8 line driver chip
9 connections in total. */

	if (!7seg_fitted)
	{
		mmtr_data = data;
		if (mmtr_data)
		{
			pia_set_input_a(4, mmtr_data | 0x80);
			for (meter = 0; meter < 8; meter ++)
			if (mmtr_data & (1 << meter))	Mechmtr_update(meter, cycles, mmtr_data & (1 << meter));
		}
		else
		{
			pia_set_input_a(4, mmtr_data &~0x80);
		}

		LOG(("%04x IC7 PIA Port A Set to %2x (Meters, Reel E and F)\n", activecpu_get_previouspc(),data));
	}
}

static WRITE8_HANDLER( pia_ic4_portb_w )
{
	LOG_IC3(("%04x IC4 PIA Port B Set to %2x (lamp strobes 1 - 9)\n", activecpu_get_previouspc(),data));

	if(decoder_active)
	{
		lamp_strobe = data;
		update_lamps();
	}
}

static WRITE8_HANDLER( pia_ic4_ca2_w )
{
	LOG_IC8(("%04x IC4 PIA write CA2 (input_strobe bit 1 / LED B) %02X\n", activecpu_get_previouspc(), data & 0xFF));

	decoder_A1 = data;
	decoder_update();
}

static WRITE8_HANDLER( pia_ic4_cb2_w )
{
	ic4_triac = data;
	triac_update();
}

static const pia6821_interface pia_ic4_intf =
{
	/*inputs : A/B,CA/B1,CA/B2 */ 0, 0, 0, 0, 0, 0,
	/*outputs: A/B,CA/B2       */ pia_ic4_porta_w, pia_ic4_portb_w, pia_ic4_ca2_w, pia_ic4_cb2_w,
	/*irqs   : A/B             */ 0, 0
};



static WRITE8_HANDLER( pia_ic5_porta_w )
{
	int i;
	LOG(("%04x IC5 PIA Port A Set to %2x \n", activecpu_get_previouspc(),data));

	/*  if ( pia_get_output_cb2(1)) */
	{
		for (i=0; x<4; i++)
		{
			Stepper_update(i, ((data >> ((i+1)*2) & 0x03));

			if ( Stepper_optic_state(i) ) optic_pattern |=  1<<i;
			else                          optic_pattern &= ~1<<i;

		draw_reel((i));
		}
	}

}

static WRITE8_HANDLER( pia_ic5_ca2_w )
{
	LOG_IC8(("%04x IC5 PIA write CA2 (input_strobe bit 2 / LED C) %02X\n", activecpu_get_previouspc(), data & 0xFF));

	decoder_A2 = data;
	decoder_update();
}

static WRITE8_HANDLER( pia_ic5_cb2_w )
{
	ic5_triac = data;
	triac_update();
}

static const pia6821_interface pia_ic5_intf =
{
	/*inputs : A/B,CA/B1,CA/B2 */ 0, 0, 0, 0, 0, 0,
	/*outputs: A/B,CA/B2       */ pia_ic5_porta_w, 0, pia_ic5_ca2_w, pia_ic5_cb2_w,
	/*irqs   : A/B             */ 0, 0
};

static WRITE8_HANDLER( pia_ic6_porta_w )
{
	alpha_data_line = data;
	ROC10937_draw_16seg(0);
}

static void decoder_update(void)
{
	{
		if ( decoder_A0 ) input_strobe |= 0x01;
		else              input_strobe &= ~0x01;

		if ( decoder_A1 ) input_strobe |= 0x02;
		else              input_strobe &= ~0x02;

		if ( decoder_A2 ) input_strobe |= 0x04;
		else              input_strobe &= ~0x04;
	}
	else
//	if ((IC23G2A)||(IC23G2B))
//	{
//		input_strobe = 0x00;
//	}
}

static const pia6821_interface pia_ic6_intf =
{
	/*inputs : A/B,CA/B1,CA/B2 */ 0, 0, 0, 0, 0, 0,
	/*outputs: A/B,CA/B2       */ pia_ic6_porta_w, 0, 0,0
	/*irqs   : A/B             */ 0, 0
};


static const ptm6840_interface ptm_ic2_intf =
{
	MPU3_MASTER_CLOCK/4,
	{ 0,0,0 },
	{ ic2_o1_callback, ic2_o2_callback, ic2_o3_callback },
	cpu0_irq
};

static ADDRESS_MAP_START( mpu3_memmap, ADDRESS_SPACE_PROGRAM, 8 )
	AM_RANGE(0x0000, 0x07FF) AM_READWRITE(ram_r, ram_w) AM_BASE(&nvram) AM_SIZE(&nvram_size)
	AM_RANGE(0x8800, 0x8807) AM_READWRITE(ptm6840_0_r,ptm6840_0_w)	// 6840PTM
	AM_RANGE(0x9000, 0x9003) AM_READWRITE(pia_0_r,pia_0_w)	  	// PIA6821 IC3
	AM_RANGE(0x9800, 0x9803) AM_READWRITE(pia_1_r,pia_1_w)	  	// PIA6821 IC4
	AM_RANGE(0xA000, 0xA003) AM_READWRITE(pia_2_r,pia_2_w)	  	// PIA6821 IC5
	AM_RANGE(0xA800, 0xA803) AM_READWRITE(pia_3_r,pia_3_w)		// PIA6821 IC6
	AM_RANGE(0x8000, 0xFFFF) AM_ROM
ADDRESS_MAP_END

static MACHINE_START( mpu3 )
{
	pia_config(0,&pia_ic3_intf);
	pia_config(1,&pia_ic4_intf);
	pia_config(2,&pia_ic5_intf);
	pia_config(3,&pia_ic6_intf);

	pia_reset();

// setup 8 mechanical meters ////////////////////////////////////////////
	Mechmtr_init(8);

// setup 4 default 96 half step reels ///////////////////////////////////
	stepper_config(machine, 0, &barcrest_mpu3_reel_interface);
	stepper_config(machine, 1, &barcrest_mpu3_reel_interface);
	stepper_config(machine, 2, &barcrest_mpu3_reel_interface);
	stepper_config(machine, 3, &barcrest_mpu3_reel_interface);

// setup the standard oki MSC1937 display ///////////////////////////////
	ROC10937_init(0, MSC1937,1);	// does oldtimer use a OKI MSC1937 alpha display controller?
}

static MACHINE_DRIVER_START( mpu3 )

	MDRV_MACHINE_START(mpu3)
	MDRV_MACHINE_RESET(mpu3)
	MDRV_CPU_ADD("main", M6809, MPU3_MASTER_CLOCK/4)
	MDRV_CPU_PROGRAM_MAP(mpu3_memmap,0)

//	MDRV_TIMER_ADD_PERIODIC("50HZ",gen_50hz, HZ(100))

//	MDRV_SPEAKER_STANDARD_MONO("mono")
//	MDRV_SOUND_ADD("AY8913",AY8913, MPU4_MASTER_CLOCK/4)
//	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)

	MDRV_NVRAM_HANDLER(generic_0fill)

	MDRV_DEFAULT_LAYOUT(layout_mpu3)
MACHINE_DRIVER_END
